@@ -64,7 +64,7 @@ def dec(st):
     if st:
         return st.decode(AUGENC)
     else:
-        return ''
+        return b''
 
 
 class Augeas(object):
@@ -105,7 +105,7 @@ class Augeas(object):
         loadpath = enc(loadpath) if loadpath else ffi.NULL
 
         # Create the Augeas object
-        self.__handle = ffi.gc(lib.aug_init(root, loadpath, flags), lib.aug_close)
+        self.__handle = ffi.gc(lib.aug_init(root, loadpath, flags), lambda x: self.close)
         if not self.__handle:
             raise RuntimeError("Unable to create Augeas object!")
 
@@ -125,8 +125,8 @@ class Augeas(object):
 
         # Call the function and pass value by reference (char **)
         ret = lib.aug_get(self.__handle, enc(path), value)
-        if ret > 1:
-            raise ValueError("path specified had too many matches!")
+        if ret < 0:
+            raise ValueError("path specified had too many matches or is illegal!")
 
         return dec(ffi.string(value[0])) if value[0] != ffi.NULL else None
 
@@ -146,8 +146,8 @@ class Augeas(object):
 
         # Call the function and pass value by reference (char **)
         ret = lib.aug_label(self.__handle, enc(path), label)
-        if ret > 1:
-            raise ValueError("path specified had too many matches!")
+        if ret < 0:
+            raise ValueError("path specified had too many matches or is illegal!")
 
         return dec(ffi.string(label[0])) if label[0] != ffi.NULL else None
 
@@ -568,7 +568,7 @@ class Augeas(object):
         for any more operations."""
 
         # If we are already closed, return
-        if not self.__handle:
+        if not self.__handle or self.__handle == ffi.NULL:
             return
 
         # Call the function
